# Cache

By default, `pyfonts` caches font files to improve performance. But you can disable this behaviour by setting `use_cache=False` in the [`load_font()`](load_font.md) and [`load_google_font()`](load_google_font.md) functions, and manually clearing the cache with `clear_pyfonts_cache()`.

<br>

::: pyfonts.clear_pyfonts_cache

<br>
